@@ -17,24 +17,41 @@ cat(
   )
 )
 
+## ----installation cran, eval=FALSE--------------------------------------------
+#  install.packages("pagemap")
+
 ## ----installation, eval=FALSE-------------------------------------------------
 #  # install.packages("devtools")
 #  devtools::install_github('swsoyee/pagemapR')
 
 ## ----usage, eval=FALSE--------------------------------------------------------
-#  pagemap::pagemap(id = "mini_map")
+#  library(pagemap)
+#  pagemap()
 
 ## ----box_style, eval=FALSE----------------------------------------------------
-#  pagemap::pagemap(id = "mini_map",
-#                   box_style = list(left = "5px", top = "10px"))
+#  pagemap(id = "mini_map",
+#          box_style = list(left = "5px", top = "10px"))
+
+## ----loading pacakge, echo=FALSE----------------------------------------------
+library(pagemap)
 
 ## ----customize_pagemap--------------------------------------------------------
-pagemap::pagemap(
+pagemap(
   id = "mini_map",
   styles = list(
-    'h1,h2,a,code' = 'rgba(0,0,0,0.10)',
+    'h1,h2,a,code' = 'rgba(0, 0, 0, 0.10)',
     'img' = 'rgba(0, 0, 0, 0.08)',
-    'pre' = 'rgba(0,0,0,0.04)'
+    'pre' = 'rgba(0, 0, 0, 0.04)'
   )
 )
 
+## ----shiny demo, eval=FALSE---------------------------------------------------
+#  if (interactive()) {
+#    shinyApp(
+#      ui = fluidPage(pagemapOutput("pagemap")),
+#      server = function(input, output) {
+#        output$pagemap <- renderPagemap(pagemap())
+#      }
+#    )
+#  }
+
